==> coopui-0.16.tar.gz: coopui-0.16/coopui/cli/CliMenu.py <==
from typing import Callable, Dict, Tuple, Union, Any

class CliMenu:
    def __init__(self, menu_header: Union[str, Callable[[Any], str]],
                 definition: Dict[str,
                                  Tuple[str,
                                         Callable[[], None]
                                        ]
                                ],
                 notify_user_provider: Callable[[str], None]):
        self.notify_user_provider = notify_user_provider

        self.menu_header = menu_header
        self.menu_items = definition

    def register(self, menu_text, user_entry, action):
        self.menu_items[user_entry] = (menu_text, action)

    def loop(self, switch, request):
        while True:
            action = switch(request())
            if action is None:
                return
            elif action == "INVALID":
                self.notify_user_provider("Invalid Entry...")
            elif action is not None:
                action()
            else:
                raise NotImplementedError("Unhandled response type")

    def _resolve_menu_header(self):
        try:
            return self.menu_header()
        except:
            return str(self.menu_header)

    def print_menu(self):


        print(f"\n{self._resolve_menu_header()}")
        print("Please select option\n")

        for item, tup in self.menu_items.items():
            print(tup[0])

    def get_input_from_user(self):
        self.print_menu()
        return input("").upper()

    def run(self):
        switch = lambda x: {item: tup[1] for item, tup in self.menu_items.items()}.get(x, "INVALID")
        self.loop(switch, self.get_input_from_user)

==> coopui-0.17.tar.gz: coopui-0.17/coopui/cli/CliMenu.py <==
from typing import Callable, Dict, Tuple
import logging
import traceback
# https://stackoverflow.com/questions/384076/how-can-i-color-python-logging-output

MENU = 51
logging.addLevelName(MENU, 'MENU')
logger = logging.getLogger('CLIMENU')

def _try_action(action):
    try:
        action()
    except Exception as e:
        stack = traceback.format_exc()
        logger.error(f"{e}"
                     f"\n{stack}")

class CliMenu:
    def __init__(self, menu_header: str,
                 definition: Dict[str,
                                  Tuple[str,
                                         Callable[[], None]
                                        ]
                                ],
                 notify_user_provider: Callable[[str], None]):
        self.notify_user_provider = notify_user_provider

        self.menu_header = menu_header
        self.menu_items = definition

    def register(self, menu_text, user_entry, action):
        self.menu_items[user_entry] = (menu_text, action)

    def loop(self, switch, request):
        while True:
            action = switch(request())
            if action is None:
                return
            elif action == "INVALID":
                self.notify_user_provider("Invalid Entry...")
            elif action is not None:
                _try_action(action)
            else:
                raise NotImplementedError("Unhandled response type")


    def print_menu(self):
        print(f"\n{self.menu_header}")
        print("Please select option\n")

        for item, tup in self.menu_items.items():
            print(tup[0])

    def get_input_from_user(self):
        self.print_menu()
        return input("").upper()

    def run(self):
        switch = lambda x: {item: tup[1] for item, tup in self.menu_items.items()}.get(x, "INVALID")
        self.loop(switch, self.get_input_from_user)
